@@ -1,5 +1,5 @@
 /* GNOME-Mud - A simple Mud CLient
- * Copyright (C) 1999-2001 Robin Ericsson <lobbin@localhost.nu>
+ * Copyright (C) 1999-2006 Robin Ericsson <lobbin@localhost.nu>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  */
 
 /*
-** This module/plug-in API is slighly based on the API in gEdit. 
+** This module/plug-in API is slighly based on the API in gEdit.
 */
 
 #ifndef __MODULES_C__
@@ -27,13 +27,10 @@
 #  include "config.h"
 #endif
 
-#include <errno.h>
-#include <gnome.h>
-#include <stdio.h>
-#include <sys/stat.h>
-#include <unistd.h>
+#include <gconf/gconf-client.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <string.h>
-#include <pwd.h>
 
 #if HAVE_DIRENT_H
 # include <dirent.h>
@@ -52,29 +49,31 @@
 # endif
 #endif
 
+#include <gmodule.h>
 #include "gnome-mud.h"
+#include "mud-connection-view.h"
+#include "mud-window.h"
 #include "modules.h"
-
-static char const rcsid[] =
-    "$Id: modules.c,v 1.26 2003/07/11 01:22:10 jordim Exp $";
+#include "modules_api.h"
 
 GList     *Plugin_list;
 GList     *Plugin_data_list;
 int       plugin_selected_row;
 gint       amount;
+MudWindow *gGMudWindow;
 
-PLUGIN_OBJECT *plugin_get_plugin_object_by_handle (gint handle)
+PLUGIN_OBJECT *plugin_get_plugin_object_by_handle (GModule  *handle)
 {
   PLUGIN_OBJECT *p;
   GList         *t;
 
   for (t = g_list_first(Plugin_list); t != NULL; t = t->next) {
-      
+
     if (t->data != NULL) {
       p = (PLUGIN_OBJECT *) t->data;
 
-      if (GPOINTER_TO_INT(p->handle) == handle)
-	return p;
+      if (p->handle == handle)
+		return p;
     }
   }
 
@@ -91,14 +90,14 @@ PLUGIN_OBJECT static *plugin_get_plugin_object_by_name (gchar *name)
 		if (t->data != NULL)
 		{
 			p = (PLUGIN_OBJECT *) t->data;
-      
+
 			if (!strcmp (p->info->plugin_name, name))
 			{
 				return p;
 			}
 		}
 	}
-    
+
 	return NULL;
 }
 
@@ -106,22 +105,26 @@ static void plugin_enable_check_cb (GtkWidget *widget, gpointer data)
 {
   PLUGIN_OBJECT *p;
   gchar *text;
-  
+  GConfClient *client;
+  GError *err = NULL;
+
+  client = gconf_client_get_default();
+
   gtk_clist_get_text ((GtkCList *) data, plugin_selected_row, 0, &text);
 
   p = plugin_get_plugin_object_by_name (text);
 
   if (p != NULL) {
-    gchar path[50];
+    gchar path[128];
 
     if (GTK_TOGGLE_BUTTON (widget)->active) {
-      p->enabeled = TRUE;
+      p->enabled = TRUE;
     } else {
-      p->enabeled = FALSE;
+      p->enabled = FALSE;
     }
 
-    g_snprintf(path, 50, "/gnome-mud/Plugins/%s", p->name);
-    gnome_config_set_bool(path, p->enabeled);
+    g_snprintf(path, 128, "/apps/gnome-mud/Plugins/%s/enbl", p->name);
+    gconf_client_set_bool(client, path, p->enabled, &err);
   }
 }
 
@@ -139,15 +142,15 @@ static void plugin_clist_select_row_cb (GtkWidget *clist, gint r, gint c, GdkEve
 	{
 		GtkTextBuffer *buffer;
 		GtkWidget *plugin_desc_text = gtk_object_get_data(GTK_OBJECT(clist), "plugin_desc_text");
-	  
+
 		gtk_entry_set_text (GTK_ENTRY (gtk_object_get_data(GTK_OBJECT(clist), "plugin_name_entry")),    p->info->plugin_name);
 		gtk_entry_set_text (GTK_ENTRY (gtk_object_get_data(GTK_OBJECT(clist), "plugin_author_entry")),  p->info->plugin_author);
 		gtk_entry_set_text (GTK_ENTRY (gtk_object_get_data(GTK_OBJECT(clist), "plugin_version_entry")), p->info->plugin_version);
 
 		buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(plugin_desc_text));
 		gtk_text_buffer_set_text(buffer, p->info->plugin_descr, -1);
-    
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_object_get_data(GTK_OBJECT(clist), "plugin_enable_check")), p->enabeled);
+
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_object_get_data(GTK_OBJECT(clist), "plugin_enable_check")), p->enabled);
 	}
 }
 
@@ -184,20 +187,20 @@ void do_plugin_information(GtkWidget *widget, gpointer data)
   GtkWidget *plugin_version_entry;
   GtkWidget *plugin_desc_text;
   GtkWidget *plugin_enable_check;
-  
+
   if (dialog1 != NULL) {
     gtk_window_present (GTK_WINDOW (dialog1));
     return;
   }
 
-  dialog1 = gnome_dialog_new (NULL, NULL);
+  dialog1 = gtk_dialog_new();
   gtk_object_set_data (GTK_OBJECT (dialog1), "dialog1", dialog1);
   gtk_widget_set_usize (dialog1, 430, -2);
- 
+
   gtk_window_set_title(GTK_WINDOW(dialog1), _("Plugin Information"));
   gtk_window_set_policy (GTK_WINDOW (dialog1), FALSE, FALSE, FALSE);
 
-  dialog_vbox1 = GNOME_DIALOG (dialog1)->vbox;
+  dialog_vbox1 = GTK_DIALOG (dialog1)->vbox;
   gtk_object_set_data (GTK_OBJECT (dialog1), "dialog_vbox1", dialog_vbox1);
   gtk_widget_show (dialog_vbox1);
 
@@ -331,14 +334,13 @@ void do_plugin_information(GtkWidget *widget, gpointer data)
   gtk_widget_show(plugin_desc_text);
   gtk_container_add(GTK_CONTAINER(scrolledwindow2), plugin_desc_text);
 
-  dialog_action_area1 = GNOME_DIALOG (dialog1)->action_area;
+  dialog_action_area1 = GTK_DIALOG (dialog1)->action_area;
   gtk_object_set_data (GTK_OBJECT (dialog1), "dialog_action_area1", dialog_action_area1);
   gtk_widget_show (dialog_action_area1);
   gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1), GTK_BUTTONBOX_END);
   gtk_button_box_set_spacing (GTK_BUTTON_BOX (dialog_action_area1), 8);
 
-  gnome_dialog_append_button (GNOME_DIALOG (dialog1), GNOME_STOCK_BUTTON_CLOSE);
-  button1 = GTK_WIDGET (g_list_last (GNOME_DIALOG (dialog1)->buttons)->data);
+  button1 = gtk_dialog_add_button(GTK_DIALOG(dialog1), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
   gtk_widget_ref (button1);
   gtk_object_set_data_full (GTK_OBJECT (dialog1), "button1", button1,
                             (GtkDestroyNotify) gtk_widget_unref);
@@ -360,11 +362,11 @@ void do_plugin_information(GtkWidget *widget, gpointer data)
   gtk_object_set_data(GTK_OBJECT(clist1), "plugin_author_entry",  plugin_author_entry);
   gtk_object_set_data(GTK_OBJECT(clist1), "plugin_version_entry", plugin_version_entry);
   gtk_object_set_data(GTK_OBJECT(clist1), "plugin_desc_text",     plugin_desc_text);
-  gtk_object_set_data(GTK_OBJECT(clist1), "plugin_enable_check",  plugin_enable_check);  
+  gtk_object_set_data(GTK_OBJECT(clist1), "plugin_enable_check",  plugin_enable_check);
 
   g_list_foreach (Plugin_list, (GFunc) plugin_clist_append, clist1);
   gtk_clist_select_row (GTK_CLIST (clist1), 0, 0);
- 
+
   gtk_widget_show(dialog1);
 }
 
@@ -375,35 +377,35 @@ int init_modules(char *path)
   gchar          *shortname;
 
   if ((directory = opendir(path)) == NULL) {
-    g_message("Plugin error (%s): %s", path, strerror(errno));
+    g_message(_("Plugin error (%s)"), path);
     return FALSE;
   }
-  
+
   while ((direntity = readdir(directory))) {
     PLUGIN_OBJECT *plugin;
     gchar *suffix;
-    
+
     if (strrchr(direntity->d_name, '/'))
       shortname = (gchar *) strrchr(direntity->d_name, '/') + 1;
     else
       shortname = direntity->d_name;
-    
+
     if (!strcmp(shortname, ".") || !strcmp(shortname, ".."))
       continue;
-    
+
     suffix = (gchar *) strrchr(direntity->d_name, '.');
     if (!suffix || strcmp(suffix, ".plugin"))
       continue;
-    
+
     plugin = plugin_query(direntity->d_name, path);
     if (!plugin)
       continue;
-    
+
     plugin_register(plugin);
   }
-  
+
   closedir(directory);
-  
+
   return TRUE;
 }
 
@@ -414,14 +416,20 @@ PLUGIN_OBJECT *plugin_query (gchar *plugin_name, gchar *plugin_path)
 
     new_plugin->name = g_strdup(plugin_name);
     sprintf (filename, "%s%s", plugin_path, plugin_name);
-    if ((new_plugin->handle = dlopen (filename, RTLD_LAZY)) == NULL)
+
+	new_plugin->handle = g_module_open(filename, G_MODULE_BIND_LAZY);
+
+    if(new_plugin == NULL)
     {
-        g_message (_("Error getting plugin handle (%s): %s."), plugin_name, dlerror());
+        g_message (_("Error getting plugin handle (%s): %s."), plugin_name, g_module_error());
         goto error;
     } else {
-        if ((new_plugin->info = dlsym(new_plugin->handle,"gnomemud_plugin_info")) == NULL)
+        void *data = &new_plugin->info;
+        gpointer *info = (gpointer *)data;
+
+ 		if(!g_module_symbol(new_plugin->handle, "gnomemud_plugin_info", info))
         {
-            g_message (_("Error, %s not an GNOME-Mud module: %s."), plugin_name, dlerror());
+            g_message (_("Error, %s not an GNOME-Mud module: %s."), plugin_name, g_module_error());
             goto error;
         }
         new_plugin->filename = g_strdup (filename);
@@ -438,23 +446,41 @@ error:
 
 static void plugin_check_enable(PLUGIN_OBJECT *plugin)
 {
-  gchar path[50];
+  gchar path[128];
+  GConfClient *client;
+  GError *err = NULL;
 
-  g_snprintf(path, 50, "/gnome-mud/Plugins/%s=false", plugin->name);
+  client = gconf_client_get_default();
 
-  plugin->enabeled = gnome_config_get_bool(path);
+  g_snprintf(path, 128, "/apps/gnome-mud/Plugins/%s/enbl", plugin->name);
+
+  plugin->enabled = gconf_client_get_bool(client, path, &err);
 }
 
 void plugin_register(PLUGIN_OBJECT *plugin)
 {
-    g_message (_("Registering plugin `%s' under the name `%s'."), plugin->name, plugin->info->plugin_name);
-
     plugin_check_enable(plugin);
 
     Plugin_list = g_list_append(Plugin_list, (gpointer) plugin);
-    
+
     if (plugin->info->init_function) {
-      plugin->info->init_function(NULL, GPOINTER_TO_INT(plugin->handle));
+      plugin->info->init_function(NULL, plugin->handle);
     }
 }
+void popup_message(const gchar *data)
+{
+	GtkWidget *dialog;
+
+	dialog = gtk_message_dialog_new(NULL, 0, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, "%s", data);
+
+	gtk_dialog_run(GTK_DIALOG(dialog));
+	gtk_widget_destroy(dialog);
+}
+
+void
+init_modules_win(MudWindow *win)
+{
+	gGMudWindow = win;
+}
+
 #endif
